aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--gtk/rpc_progs.c10
-rw-r--r--tap-rpcprogs.c6
2 files changed, 8 insertions, 8 deletions
diff --git a/gtk/rpc_progs.c b/gtk/rpc_progs.c
index c7d65c9fed..c64d429646 100644
--- a/gtk/rpc_progs.c
+++ b/gtk/rpc_progs.c
@@ -1,7 +1,7 @@
/* rpc_progs.c
* rpc_progs 2002 Ronnie Sahlberg
*
- * $Id: rpc_progs.c,v 1.23 2004/04/12 09:48:18 ulfl Exp $
+ * $Id: rpc_progs.c,v 1.24 2004/05/17 20:06:32 sahlberg Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -22,7 +22,7 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* This module provides rpc call/reply RTT statistics to tethereal.
* It is only used by tethereal and not ethereal
*
* It serves as an example on how to use the tap api.
@@ -370,15 +370,15 @@ gtk_rpcprogs_init(char *optarg _U_)
gtk_table_attach_defaults(GTK_TABLE(table), tmp, 2,3,0,1);
gtk_label_set_justify(GTK_LABEL(tmp), GTK_JUSTIFY_RIGHT);
- tmp=gtk_label_new("Min RTT");
+ tmp=gtk_label_new("Min SRT");
gtk_table_attach_defaults(GTK_TABLE(table), tmp, 3,4,0,1);
gtk_label_set_justify(GTK_LABEL(tmp), GTK_JUSTIFY_RIGHT);
- tmp=gtk_label_new("Max RTT");
+ tmp=gtk_label_new("Max SRT");
gtk_table_attach_defaults(GTK_TABLE(table), tmp, 4,5,0,1);
gtk_label_set_justify(GTK_LABEL(tmp), GTK_JUSTIFY_RIGHT);
- tmp=gtk_label_new("Avg RTT");
+ tmp=gtk_label_new("Avg SRT");
gtk_table_attach_defaults(GTK_TABLE(table), tmp, 5,6,0,1);
gtk_label_set_justify(GTK_LABEL(tmp), GTK_JUSTIFY_RIGHT);
@@ -22,7 +22,7 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* This module provides rpc call/reply RTT statistics to tethereal.
+/* This module provides rpc call/reply SRT statistics to tethereal.
* It is only used by tethereal and not ethereal
*
diff --git a/tap-rpcprogs.c b/tap-rpcprogs.c
index 7b6155a6fc..51454e8582 100644
--- a/tap-rpcprogs.c
+++ b/tap-rpcprogs.c
@@ -1,7 +1,7 @@
/* tap-rpcprogs.c
* rpcstat 2002 Ronnie Sahlberg
*
- * $Id: tap-rpcprogs.c,v 1.5 2003/04/23 08:20:02 guy Exp $
+ * $Id: tap-rpcprogs.c,v 1.6 2004/05/17 20:06:32 sahlberg Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -22,7 +22,7 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* This module provides rpc call/reply RTT statistics to tethereal.
* It is only used by tethereal and not ethereal
*/
@@ -193,7 +193,7 @@ rpcprogs_draw(void *dummy _U_)
printf("\n");
printf("===================================================================\n");
printf("ONC-RPC Program Statistics:\n");
- printf("Program Version Calls Min RTT Max RTT Avg RTT\n");
+ printf("Program Version Calls Min SRT Max SRT Avg SRT\n");
for(rp=prog_list;rp;rp=rp->next){
/* scale it to units of 10us.*/
/* for long captures with a large tot time, this can overflow on 32bit */
@@ -22,7 +22,7 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* This module provides rpc call/reply RTT statistics to tethereal.
+/* This module provides rpc call/reply SRT statistics to tethereal.
* It is only used by tethereal and not ethereal
*/